@@ -13,7 +13,7 @@
 Tools for the impurity caluclation plugin and its workflows
 """
 from numpy import array, ndarray, loadtxt
-from masci_tools.io.common_functions import search_string, open_general, get_version_info, convert_to_pystd
+from masci_tools.io.common_functions import search_string, get_outfile_txt, get_version_info, convert_to_pystd
 from masci_tools.io.parsers.kkrparser_functions import get_rms, find_warnings, get_charges_per_atom, get_core_states
 import traceback
 from masci_tools.io.common_functions import get_Ry2eV
@@ -47,8 +47,7 @@ class KkrimpParserFunctions:
             * 'epts', list of complex valued energy points
             * 'weights', list of complex valued weights for energy integration
         """
-        with open_general(out_log) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(out_log)
         econt = {}
         itmp = search_string('[read_energy] number of energy points', tmptxt)
         if itmp >= 0:
@@ -72,8 +71,7 @@ class KkrimpParserFunctions:
         :returns: niter (int), nitermax (int), converged (bool), nmax_reached (bool), mixinfo (dict)
         :note: mixinfo contains information on mixing scheme and mixing factor used in the calculation
         """
-        with open_general(file) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(file)
         # get rms and number of iterations
         itmp, niter, rms = 0, -1, -1
         while itmp >= 0:
@@ -119,8 +117,7 @@ class KkrimpParserFunctions:
         :param file: absolute path to out_log.000.txt of KKRimp calculation
         :returns: True(False) if SOC solver is (not) used
         """
-        with open_general(file) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(file)
         itmp = search_string('Spin orbit coupling used?', tmptxt)
         itmp = int(tmptxt.pop(itmp).split()[-1])
         newsosol = itmp == 1
@@ -132,8 +129,7 @@ class KkrimpParserFunctions:
         :param file: file that is parsed to find number of atoms
         :returns: natom (int), number of atoms in impurity cluster
         """
-        with open_general(file) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(file)
         itmp = search_string('NATOM is', tmptxt)
         natom = int(tmptxt.pop(itmp).split()[-1])
         return natom
@@ -151,8 +147,7 @@ class KkrimpParserFunctions:
         """
         import numpy as np
 
-        with open_general(file) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(file)
         itmp = 0
         spinmom_all = []
         while itmp >= 0:
@@ -181,8 +176,7 @@ class KkrimpParserFunctions:
         :param outfile: timing file of the KKRimp run
         :returns: res (dict) timings in seconds, averaged over iterations
         """
-        with open_general(outfile) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(outfile)
         search_keys = [
             'time until scf starts', 'vpot->tmat', 'gref->gmat', 'gonsite->density', 'energyloop', 'Iteration number',
             'Total running time'
@@ -202,10 +196,10 @@ class KkrimpParserFunctions:
         niter = len(res.get(search_keys[-2], []))
         if niter > 0:
             for key in search_keys[1:6]:
-                if key in list(res.keys()):
+                if key in res:
                     res[key] = sum(res[key]) / niter
             for key in [search_keys[0], search_keys[-1]]:
-                if key in list(res.keys()):
+                if key in res:
                     res[key] = res[key][0]
         return res
 
@@ -215,8 +209,7 @@ class KkrimpParserFunctions:
         :param file: file that is parsed
         :returns: 1 if calculation is paramagnetic, 2 otherwise
         """
-        with open_general(file) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(file)
         itmp = search_string('NSPIN', tmptxt)
         nspin = int(tmptxt.pop(itmp).split()[-1])
         return nspin
@@ -233,8 +226,7 @@ class KkrimpParserFunctions:
         import numpy as np
         from math import sqrt  #pylint: disable=no-name-in-module
 
-        with open_general(file) as f:
-            lines = f.readlines()
+        lines = get_outfile_txt(file)
         startline = len(lines) - natom
         spinmom_at = np.array([lines[startline].split()])
         spinmom_at_all = np.array([lines[1].split()])
@@ -263,8 +255,7 @@ class KkrimpParserFunctions:
         """
         import numpy as np
 
-        with open_general(file) as f:
-            lines = f.readlines()
+        lines = get_outfile_txt(file)
         startline = len(lines) - natom
 
         orbmom_at = []
@@ -289,8 +280,7 @@ class KkrimpParserFunctions:
         :param potfile: file that is parsed
         :returns: EF (float), value of the Fermi energy in Ry
         """
-        with open_general(potfile) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(potfile)
         EF = float(tmptxt[3].split()[1])
         return EF
 
@@ -300,8 +290,7 @@ class KkrimpParserFunctions:
         :param file: file that is parsed
         :returns: Etot (list), values of the total energy in Ry for all iterations
         """
-        with open_general(file) as f:
-            tmptxt = f.readlines()
+        tmptxt = get_outfile_txt(file)
         itmp = 0
         Etot = []
         while itmp >= 0:
@@ -356,7 +345,7 @@ class KkrimpParserFunctions:
             tmp_dict['compile_options'] = compile_options
             tmp_dict['calculation_serial_number'] = serial_number
             out_dict['code_info_group'] = tmp_dict
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: Version Info'
             msg_list.append(msg)
             if debug:
@@ -380,7 +369,7 @@ class KkrimpParserFunctions:
             tmp_dict['rms_spin_per_atom'] = result_atoms_last_spin
             tmp_dict['rms_unit'] = 'unitless'
             out_dict['convergence_group'] = tmp_dict
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: rms-error'
             msg_list.append(msg)
             if debug:
@@ -393,7 +382,7 @@ class KkrimpParserFunctions:
             out_dict['nspin'] = nspin
             out_dict['number_of_atoms_in_unit_cell'] = natom
             out_dict['use_newsosol'] = newsosol
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: nspin/natom'
             msg_list.append(msg)
             if debug:
@@ -407,7 +396,7 @@ class KkrimpParserFunctions:
                 out_dict['convergence_group']['total_spin_moment_all_iterations'] = result
                 tmp_dict['total_spin_moment_unit'] = 'mu_Bohr'
                 out_dict['magnetism_group'] = tmp_dict
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: total magnetic moment'
             msg_list.append(msg)
             if debug:
@@ -424,7 +413,7 @@ class KkrimpParserFunctions:
                     out_dict['convergence_group']['spin_moment_per_atom_all_iterations'] = spinmom_atom_vec_all_iter
                     tmp_dict['spin_moment_unit'] = 'mu_Bohr'
                     out_dict['magnetism_group'] = tmp_dict
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: spin moment per atom'
             msg_list.append(msg)
             if debug:
@@ -440,7 +429,7 @@ class KkrimpParserFunctions:
                     out_dict['convergence_group']['orbital_moment_per_atom_all_iterations'] = orbmom_atom_all_iter
                     tmp_dict['orbital_moment_unit'] = 'mu_Bohr'
                     out_dict['magnetism_group'] = tmp_dict
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: orbital moment'
             msg_list.append(msg)
             if debug:
@@ -450,7 +439,7 @@ class KkrimpParserFunctions:
             result = self._get_EF_potfile(files['out_pot'])
             out_dict['fermi_energy'] = result
             out_dict['fermi_energy_units'] = 'Ry'
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: EF'
             msg_list.append(msg)
             if debug:
@@ -463,7 +452,7 @@ class KkrimpParserFunctions:
             out_dict['total_energy_Ry'] = result[-1]
             out_dict['total_energy_Ry_unit'] = 'Rydberg'
             out_dict['convergence_group']['total_energy_Ry_all_iterations'] = result
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: total energy'
             msg_list.append(msg)
             if debug:
@@ -475,7 +464,7 @@ class KkrimpParserFunctions:
             tmp_dict['number_of_warnings'] = len(result)
             tmp_dict['warnings_list'] = result
             out_dict['warnings_group'] = tmp_dict
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: search for warnings'
             msg_list.append(msg)
             if debug:
@@ -485,7 +474,7 @@ class KkrimpParserFunctions:
             result = self._extract_timings(files['out_timing'])
             out_dict['timings_group'] = result
             out_dict['timings_unit'] = 'seconds'
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: timings'
             msg_list.append(msg)
             if debug:
@@ -497,7 +486,7 @@ class KkrimpParserFunctions:
             out_dict['single_particle_energies_unit'] = 'eV'
             out_dict['total_energies_atom'] = etot_at * get_Ry2eV()
             out_dict['total_energies_atom_unit'] = 'eV'
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: single particle energies'
             msg_list.append(msg)
             if debug:
@@ -515,7 +504,7 @@ class KkrimpParserFunctions:
             out_dict['total_charge_per_atom_unit'] = 'electron charge'
             out_dict['charge_core_states_per_atom_unit'] = 'electron charge'
             out_dict['charge_valence_states_per_atom_unit'] = 'electron charge'
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: charges'
             msg_list.append(msg)
             if debug:
@@ -531,7 +520,7 @@ class KkrimpParserFunctions:
             tmp_dict['epoints_contour_unit'] = 'Rydberg'
             tmp_dict['epoints_weights'] = econt.get('weights')
             out_dict['energy_contour_group'] = tmp_dict
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: energy contour'
             msg_list.append(msg)
             if debug:
@@ -545,7 +534,7 @@ class KkrimpParserFunctions:
             tmp_dict['energy_highest_lying_core_state_per_atom_unit'] = 'Rydberg'
             tmp_dict['descr_highest_lying_core_state_per_atom'] = descr_max
             out_dict['core_states_group'] = tmp_dict
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: core_states'
             msg_list.append(msg)
             if debug:
@@ -562,7 +551,7 @@ class KkrimpParserFunctions:
             out_dict['convergence_group']['qbound'] = mixinfo[2]
             out_dict['convergence_group']['fcm'] = mixinfo[3]
             out_dict['convergence_group']['brymix'] = mixinfo[1]
-        except:
+        except:  # pylint: disable=bare-except
             msg = 'Error parsing output of KKRimp: scfinfo'
             msg_list.append(msg)
             if debug:
