@@ -17,6 +17,8 @@ from .bokeh_plotter import BokehPlotter
 from .parameters import ensure_plotter_consistency, NestedPlotParameters
 from .data import process_data_arguments
 
+from .helpers import get_special_kpoint_ticks
+
 import pandas as pd
 import numpy as np
 import warnings
@@ -732,32 +734,25 @@ def bokeh_bands(kpath,
             plot_params.set_defaults(default_type='function',
                                      color=linear_cmap(entries.color, 'Blues256', weight_max, -0.05))
 
-        transform = lambda size: markersize_min + markersize_scaling * size / weight_max
-        plot_data.apply('size', transform)
+        plot_data.apply('size', lambda size: markersize_min + markersize_scaling * size / weight_max)
     else:
         plot_params.set_defaults(default_type='function', color='black')
 
-    if special_kpoints is None:
-        special_kpoints = []
+    xticks, xticklabels = get_special_kpoint_ticks(special_kpoints, math_mode='$$')
 
-    xticks = []
-    xticklabels = {}
-    for label, pos in special_kpoints:
-        if label in ('Gamma', 'g'):
-            label = r'$$\Gamma$$'
+    pos_to_label = {}
+    for pos, label in zip(xticks, xticklabels):
         if pos.is_integer():
-            xticklabels[int(pos)] = label
-        xticklabels[pos] = label
-        xticks.append(pos)
+            pos_to_label[int(pos)] = label
+        pos_to_label[pos] = label
 
-    lines = {'horizontal': 0}
-    lines['vertical'] = xticks
+    lines = {'horizontal': 0, 'vertical': xticks}
 
     limits = {'y': (-15, 15)}
     plot_params.set_defaults(default_type='function',
                              straight_lines=lines,
                              x_ticks=xticks,
-                             x_ticklabels_overwrite=xticklabels,
+                             x_ticklabels_overwrite=pos_to_label,
                              figure_kwargs={
                                  'width': 1280,
                                  'height': 720
@@ -909,8 +904,7 @@ def bokeh_spinpol_bands(kpath,
         mask = [np.logical_and(col.bands > ylimits[0], col.bands < ylimits[1]) for col in data]
         weight_max = plot_data.max('size', mask=mask)
 
-        transform = lambda size: markersize_min + markersize_scaling * size / weight_max
-        plot_data.apply('size', transform)
+        plot_data.apply('size', lambda size: markersize_min + markersize_scaling * size / weight_max)
 
         plot_params.set_defaults(default_type='function', marker_size=plot_data.get_keys('size'))
         if scale_color:
@@ -923,27 +917,21 @@ def bokeh_spinpol_bands(kpath,
         color = ['blue', 'red']
         plot_params.set_defaults(default_type='function', color=color)
 
-    if special_kpoints is None:
-        special_kpoints = []
+    xticks, xticklabels = get_special_kpoint_ticks(special_kpoints, math_mode='$$')
 
-    xticks = []
-    xticklabels = {}
-    for label, pos in special_kpoints:
-        if label in ('Gamma', 'g'):
-            label = r'$$\Gamma$$'
+    pos_to_label = {}
+    for pos, label in zip(xticks, xticklabels):
         if pos.is_integer():
-            xticklabels[int(pos)] = label
-        xticklabels[pos] = label
-        xticks.append(pos)
+            pos_to_label[int(pos)] = label
+        pos_to_label[pos] = label
 
-    lines = {'horizontal': 0}
-    lines['vertical'] = xticks
+    lines = {'horizontal': 0, 'vertical': xticks}
 
     limits = {'y': (-15, 15)}
     plot_params.set_defaults(default_type='function',
                              straight_lines=lines,
                              x_ticks=xticks,
-                             x_ticklabels_overwrite=xticklabels,
+                             x_ticklabels_overwrite=pos_to_label,
                              figure_kwargs={
                                  'width': 1280,
                                  'height': 720
@@ -1023,27 +1011,21 @@ def bokeh_spectral_function(kpath,
                                        },
                                        copy_data=copy_data)
 
-    if special_kpoints is None:
-        special_kpoints = []
+    xticks, xticklabels = get_special_kpoint_ticks(special_kpoints, math_mode='$$')
 
-    xticks = []
-    xticklabels = {}
-    for label, pos in special_kpoints:
-        if label in ('Gamma', 'g'):
-            label = r'$$\Gamma$$'
+    pos_to_label = {}
+    for pos, label in zip(xticks, xticklabels):
         if pos.is_integer():
-            xticklabels[int(pos)] = label
-        xticklabels[pos] = label
-        xticks.append(pos)
+            pos_to_label[int(pos)] = label
+        pos_to_label[pos] = label
 
-    lines = {'horizontal': e_fermi}
-    lines['vertical'] = xticks
+    lines = {'horizontal': e_fermi, 'vertical': xticks}
 
     limits = {'y': (plot_data.min('energy'), plot_data.max('energy'))}
     plot_params.set_defaults(default_type='function',
                              straight_lines=lines,
                              x_ticks=xticks,
-                             x_ticklabels_overwrite=xticklabels,
+                             x_ticklabels_overwrite=pos_to_label,
                              figure_kwargs={
                                  'width': 1280,
                                  'height': 720
